'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.default = transformJoiTemplateString;
// Since the language template string format of react-intl and joi-validation-streagy is not the same,
// getting the same structure of file format to be parsed for these two parsers do not work well together,
// therefore it is necessary to transform react-intl template string format to joi-validation-streagy format
// so that after running defineMessages, the stragy function is able to transform it into its validator
function transformJoiTemplateString() {
  var messages = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var updatedMessages = messages;

  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = Object.keys(messages)[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var key = _step.value;

      // the following are the whitelist of joi template string, which is extracted here:
      // https://github.com/hapijs/joi/blob/master/lib/language.js
      if (key === 'defaultMessage') {
        updatedMessages[key] = messages[key].replace('{key}', '{{key}}').replace('{!key}', '{{!key}}').replace('{valids}', '{{valids}}').replace('{pos}', '{{pos}}').replace('{reason}', '{{reason}}').replace('{n}', '{{n}}').replace('{unknownMisses}', '{{unknownMisses}}').replace('{knownMisses}', '{{knownMisses}}').replace('{limit}', '{{limit}}').replace('{version}', '{{version}}').replace('{cidr}', '{{cidr}}').replace('{ref}', '{{ref}}').replace('{scheme}', '{{scheme}}').replace('{name}', '{{name}}').replace('{!value}', '{{!value}}').replace('{pattern}', '{{pattern}}').replace('{multiple}', '{{multiple}}').replace('{from}', '{{from}}').replace('{to}', '{{to}}').replace('{type}', '{{type}}').replace('{message}', '{{message}}').replace('{peer}', '{{peer}}').replace('{peers}', '{{peers}}').replace('{main}', '{{main}}').replace('{present}', '{{present}}').replace('{missing}', '{{missing}}');
      }

      // Go one deeper level and perform the same logic for nested object
      if (_typeof(messages[key]) === 'object') {
        updatedMessages[key] = transformJoiTemplateString(messages[key]);
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return updatedMessages;
}
//# sourceMappingURL=transformJoiTemplateString.js.map